summaryrefslogtreecommitdiffstats
path: root/lib/myconfig.py
diff options
context:
space:
mode:
Diffstat (limited to 'lib/myconfig.py')
-rw-r--r--lib/myconfig.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/myconfig.py b/lib/myconfig.py
index 161088e..2e54d14 100644
--- a/lib/myconfig.py
+++ b/lib/myconfig.py
@@ -142,13 +142,13 @@ class MyConfig:
return 9 # minimum word occurrence in n-gram table
def getPartialWordThreshold(self):
- return 0.10 # the first 10% in position
+ return 0.50 # the first 50% in position
def getNewWordThreshold(self):
- return 0.10 / 2 # the first 5% in position
+ return 0.50 # the first 50% in position, subject verb object.
def getMinimumEntropy(self):
- return 1.
+ return 0.3
def getMaximumIteration(self):
return 20 # roughly around N